@@ -18,29 +18,37 @@
 #   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 
 #set -x
-verbose=0
-if [ x$1 = x"" ]; then 
-    export verbose=0
-else
-    export verbose=1
-fi
+#verbose=0
+#if [ x$1 = x"" ]; then 
+#    export verbose=0
+#else
+#    export verbose=1
+#fi
+source $(dirname $0)/regexf_unittest.sh
+#source ./regexf_unittest.sh
 
 export PATH=.:$PATH
-source regexf_unittest.sh
 
+# no_match returns false=1, match returns true=0
 configFile=/usr/local/bin/regexf.ini
-assertEquals "regexf aa/bb/cc" "$configFile:re.match<aa/bb/cc> no_match"
-assertEquals "regexf aa/bb/cc vac/bb/cc" "$configFile:re.match<aa/bb/cc> no_match"
-assertContains "regexf vac/bb/cc -v" " match"
-assertContains "regexf -i -f $configFile" "regexf_version"
-
 test_file=/usr/local/bin/regexf_test.ini
 
-#test_file
-#echo "[tango]
-#patterns=
-#    ^([amk])/(\w+)/(\w+)$" > $test_file
+assertEquals "regexf aa/bb/cc" "$configFile:re.match<aa/bb/cc> no_match"
+assertFalse "regexf aa/bb/cc"
+
+assertEquals "regexf aa/bb/cc vac/bb/cc" "$configFile:re.match<aa/bb/cc> no_match"
+assertGrep "regexf vac/bb/cc -v" " match"
+assertTrue "regexf vac/bb/cc"
+
+assertGrep "regexf -i -f $configFile" "regexf_version"
 
 assertEquals "regexf -f $test_file aa/bb/cc" "$test_file:re.match<aa/bb/cc> no_match"
+assertFalse "regexf -f $test_file aa/bb/cc"
 assertEquals "regexf -f $test_file m/bb/cc" ""
-#rm $test_file
+assertGrep "regexf -f $test_file -s ego -i" "A-Za-z"
+assertGrep "regexf -f $test_file -s ego aa/bb/cc" "$test_file:re.match<aa/bb/cc> no_match"
+assertGrep "regexf -f $test_file  a/bb/cc -v" " match"
+assertGrep "regexf -f $test_file  b/bb/cc -v" " no_match"
+assertGrep "regexf -f $test_file V1:A_B/bb/cc -v" " no_match"
+assertGrep "regexf -f $test_file -s ego V1:A_B/bb/cc -v" " match"
+assertGrep "regexf -f $test_file -s ego V2:A_B/bb/cc -v" " no_match"
