@@ -1,6 +1,6 @@
 #!/bin/bash
 #   author:martinmhan@yahoo.com date:  22/04/2014
-#   regexf  find regular expressions
+#   unittest  Provide unit tests. Must be sourced
 #   Copyright (C) <2014>  <Martin Mohan>
 #
 #   This program is free software; you can redistribute it and/or modify
@@ -17,12 +17,14 @@
 #   along with this program; if not, write to the Free Software Foundation,
 #   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 
-#echo "$0 verbose=$verbose"
-#if (($verbose > 0));then
-#    echo "TestSummary: Expected: Actual:"
-#else
-#    echo "TestSummary"
-#fi
+verbose=0
+#To use this file add to your script "source ./unittest.sh"
+
+TRUE=0
+FALSE=1
+
+PASS=0
+FAIL=1
 
 # eval command and check if expected = actual
 function assertEquals()
@@ -31,35 +33,25 @@ function assertEquals()
     expected=$2;
     if [ "$expected" != "$actual" ]; then
         echo "fail:$1 expected: $expected actual: $actual"
-        return -1
+        return $FAIL
     else
-        if (($verbose > 0));then
-            echo "pass: $actual $expected"
-            return -1
-        else
-            echo pass: $1
-            return 0
-        fi
+        echo pass: $1
+        return $PASS
     fi
 }
 
-# eval command and check if expected = actual
-function assertContains()
+# eval command and check if actual results contains expected values
+function assertGrep()
 {
-#    echo "assertContains(): $0 $1 $2"
+#    echo "assertGrep(): $0 $1 $2"
     actual="`eval $1`"
-    part_string=$2;
+    grep_string=$2;
 
-    if [[ "$actual" =~ "$part_string" ]]; then
-        if (($verbose > 0));then
-            echo "pass: $1 $part_string contained in $actual"
-            return -1
-        else
-            echo pass: $1
-            return 0
-        fi
+    if [[ "$actual" =~ "$grep_string" ]]; then
+        echo pass: $1
+        return $PASS
     else
-        echo "fail:$1 expected_part: $part_string actual: $actual"
+        echo "fail:$1 expected_part: $grep_string actual: $actual"
     fi
 }
 
@@ -68,11 +60,11 @@ function assertTrue()
 {
     actual=`eval $1`
     if [ $? -eq 0 ]; then
-        echo "pass assertTrue $1 $actual"
-        return 0
+        echo "pass: assertTrue $1"
+        return $PASS
     else
-        echo "fail assertTrue $1 $actual"
-        return 1
+        echo "fail: assertTrue $1 $actual"
+        return $FAIL
     fi
 }
 
@@ -81,10 +73,10 @@ function assertFalse()
 {
     actual=`eval $1`
     if [ $? -eq 0 ]; then
-        echo "fail assertFalse $1 $actual"
-        return 0
+        echo "fail: assertFalse $1 $actual"
+        return $PASS
     else
-        echo "pass assertFalse $1 $actual"
-        return 1
+        echo "pass: assertFalse $1"
+        return $FAIL
     fi
 }
